#

##

##

###

##

##

    	apoplast

    	docker
    		docker network create --subnet=192.168.0.0/24 container_network
    		docker run --network container_network --ip 192.168.0.100 -v .:/apoplast -v /online/vaccines_apoplast/mints/apoplast:/online/vaccines_apoplast/mints/apoplast -it jumps:v2.1.0
    		docker exec -it c416670e219c bash

    	poetry
    		pip install poetry poetry-plugin-export

    		installations
    			poetry config virtualenvs.path /path/to/your/directory

    			#
    			#	if dev dependencies
    			#
    			poetry export --with dev --format requirements.txt --output requirements.txt

    			poetry export --format requirements.txt --output requirements.txt
    			pip install -r requirements.txt -t /apoplast/venues/stages_pip

    		poetry env use python3
    		poetry shell

    		/root/.cache/pypoetry/virtualenvs/apoplast-p2eJTVsK-py3.10/lib/python3.10/site-packages/

    		cp -R /root/.cache/pypoetry/virtualenvs/apoplast-p2eJTVsK-py3.10/lib/python3.10/site-packages/ /apoplast/venues/stages_pip

    	publishing
    		python3 /apoplast/venues/stages/apoplast/__status/status.proc.py
    		python3 /apoplast/venues/stages/apoplast/__status/status_API.proc.py
    		cp /apoplast/venues/stages/apoplast/room.md /apoplast/readme.md

    		#
    		#	poetry auth
    		#

    		rm -rf dist && poetry build --verbose && poetry publish --verbose;

    		# rm -rf stages_pip && pip install apoplast -t stages_pip

    	important
    		poetry show --tree